Index: Source/core/dom/Attr.h |
diff --git a/Source/core/dom/Attr.h b/Source/core/dom/Attr.h |
index 579a5d86465df167fa5702a4afce331e8374e0e6..4e83f0ee86b89a61a904ea3d652f3914fc1e8997 100644 |
--- a/Source/core/dom/Attr.h |
+++ b/Source/core/dom/Attr.h |
@@ -52,6 +52,12 @@ public: |
void setValue(const AtomicString&, ExceptionState&); |
void setValue(const AtomicString&); |
+ const AtomicString& valueForBindings() const; |
+ void setValueForBindings(const AtomicString&); |
+ |
+ virtual String nodeValue() const OVERRIDE { return value(); } |
+ virtual void setNodeValue(const String&) OVERRIDE; |
+ |
const QualifiedName& qualifiedName() const { return m_name; } |
void attachToElement(Element*); |
@@ -70,8 +76,6 @@ private: |
virtual String nodeName() const OVERRIDE { return name(); } |
virtual NodeType nodeType() const OVERRIDE { return ATTRIBUTE_NODE; } |
- virtual String nodeValue() const OVERRIDE { return value(); } |
- virtual void setNodeValue(const String&) OVERRIDE; |
virtual PassRefPtr<Node> cloneNode(bool deep = true) OVERRIDE; |
virtual bool isAttributeNode() const OVERRIDE { return true; } |
@@ -82,7 +86,7 @@ private: |
Attribute& elementAttribute(); |
// Attr wraps either an element/name, or a name/value pair (when it's a standalone Node.) |
// Note that m_name is always set, but m_element/m_standaloneValue may be null. |
Element* m_element; |
QualifiedName m_name; |
AtomicString m_standaloneValue; |
@@ -82,7 +86,7 @@ private: |
Attribute& elementAttribute(); |
// Attr wraps either an element/name, or a name/value pair (when it's a standalone Node.) |
- // Note that m_name is always set, but m_element/m_standaloneValue may be null. |
+ // m_name is always set. When m_element is null m_standaloneValue is not exposed to bindings. |
Element* m_element; |
QualifiedName m_name; |